@@ -7,21 +7,19 @@ use warnings;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.062'; # VERSION
 
 #------------------------------------------------------------------------------
 
 ## no critic qw(PackageVars);
-our $current_utc_time     = undef;
-our $current_time_offset  = undef;
-our $current_username     = undef;
-our $current_author_id    = undef;
-our $is_interactive       = undef;
+our $current_time    = undef;
+our $current_user    = undef;
+our $is_interactive  = undef;
 
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
@@ -33,11 +31,11 @@ Pinto::Globals - Global variables used across the Pinto utilities
 
 =head1 VERSION
 
-version 0.065_04
+version 0.062
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -47,3 +45,6 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
